aboutsummaryrefslogtreecommitdiff
path: root/src/runtime/runtime2.go
diff options
context:
space:
mode:
authorMark Freeman <mark@golang.org>2025-05-05 12:33:46 -0400
committerGopher Robot <gobot@golang.org>2025-05-06 12:12:10 -0700
commitd365f2266df98985f19705717ff8cf4ad3e743dc (patch)
tree83b243b5c4de00df69a5d8e7c2d6967a3ea9e12d /src/runtime/runtime2.go
parent92e23b683f01fe581a0e14b5658f0c59d9ce0d38 (diff)
downloadgo-d365f2266df98985f19705717ff8cf4ad3e743dc.tar.xz
runtime: replace mentions of "raised" with "panicked"
Fixes #73526 Change-Id: I4b801cf3e54b99559e6d5ca8fdb2fd0692a0d3a5 Reviewed-on: https://go-review.googlesource.com/c/go/+/669975 TryBot-Bypass: Mark Freeman <mark@golang.org> Reviewed-by: Robert Griesemer <gri@google.com> Auto-Submit: Mark Freeman <mark@golang.org> Reviewed-by: Mark Freeman <mark@golang.org>
Diffstat (limited to 'src/runtime/runtime2.go')
-rw-r--r--src/runtime/runtime2.go2
1 files changed, 1 insertions, 1 deletions
diff --git a/src/runtime/runtime2.go b/src/runtime/runtime2.go
index 05cf345baf..5f36015e99 100644
--- a/src/runtime/runtime2.go
+++ b/src/runtime/runtime2.go
@@ -1013,7 +1013,7 @@ type _panic struct {
slotsPtr unsafe.Pointer
recovered bool // whether this panic has been recovered
- reraised bool // whether this panic was reraised
+ repanicked bool // whether this panic repanicked
goexit bool
deferreturn bool
}